@@ -29,16 +29,16 @@ class TestConfDict(unittest.TestCase):
         c['bool'] = 'I am so true!'
         c['int']  = '6'
         self.assertTrue(c['bool'] is True)
-        self.assertEquals(c['int'], 6)
+        self.assertEqual(c['int'], 6)
         self.assertRaises(ValueError, lambda: c.update(int='not an int'))
 
     def test_load_dict(self):
         c = ConfigDict()
         d = dict(a=dict(b=dict(foo=5, bar=6), baz=7))
         c.load_dict(d)
-        self.assertEquals(c['a.b.foo'], 5)
-        self.assertEquals(c['a.b.bar'], 6)
-        self.assertEquals(c['a.baz'], 7)
+        self.assertEqual(c['a.b.foo'], 5)
+        self.assertEqual(c['a.b.bar'], 6)
+        self.assertEqual(c['a.baz'], 7)
    
 if __name__ == '__main__': #pragma: no cover
     unittest.main()
