@@ -299,7 +299,7 @@ class TestRequest(unittest.TestCase):
         e['wsgi.input'].seek(0)
         e['HTTP_TRANSFER_ENCODING'] = 'chunked'
         if isinstance(expect, str):
-            self.assertEquals(tob(expect), BaseRequest(e).body.read())
+            self.assertEqual(tob(expect), BaseRequest(e).body.read())
         else:
             self.assertRaises(expect, lambda: BaseRequest(e).body)
 
@@ -328,7 +328,7 @@ class TestRequest(unittest.TestCase):
 
     def test_multipart(self):
         """ Environ: POST (multipart files and multible values per key) """
-        fields = [('field1','value1'), ('field2','value2'), ('field2','value3')]
+        fields = [('field1','value1'), ('field2','value2'), ('field2','万难')]
         files = [('file1','filename1.txt','content1'), ('万难','万难foo.py', 'ä\nö\rü')]
         e = tools.multipart_environ(fields=fields, files=files)
         request = BaseRequest(e)
@@ -358,10 +358,13 @@ class TestRequest(unittest.TestCase):
         self.assertEqual('value1', request.POST['field1'])
         self.assertTrue('field1' not in request.files)
         self.assertEqual('value1', request.forms['field1'])
+        print(request.forms.dict, request.forms.recode_unicode)
+        self.assertEqual('万难', request.forms['field2'])
+        self.assertEqual(touni('万难'), request.forms.field2)
         # Field (multi)
         self.assertEqual(2, len(request.POST.getall('field2')))
-        self.assertEqual(['value2', 'value3'], request.POST.getall('field2'))
-        self.assertEqual(['value2', 'value3'], request.forms.getall('field2'))
+        self.assertEqual(['value2', '万难'], request.POST.getall('field2'))
+        self.assertEqual(['value2', '万难'], request.forms.getall('field2'))
         self.assertTrue('field2' not in request.files)
 
     def test_json_empty(self):
@@ -578,7 +581,7 @@ class TestResponse(unittest.TestCase):
     def test_content_type(self):
         rs = BaseResponse()
         rs.content_type = 'test/some'
-        self.assertEquals('test/some', rs.headers.get('Content-Type'))
+        self.assertEqual('test/some', rs.headers.get('Content-Type'))
 
     def test_charset(self):
         rs = BaseResponse()
